StandardIndicator class

Inheritance

Constructors

StandardIndicator({double? top, double? left, double? right, double? bottom, double? width, double? height, BorderRadius? radius, Color? color})

Properties

bottom ↔ double?
getter/setter pairinherited
color ↔ Color?
getter/setter pairinherited
controller ↔ ViewTabBarController
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double?
getter/setter pairinherited
left ↔ double?
getter/setter pairinherited
radius ↔ BorderRadius?
getter/setter pairinherited
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top ↔ double?
getter/setter pairinherited
width ↔ double?
getter/setter pairinherited

Methods

indicatorScrollToIndex(int index, List<Size>? sizeList, ValueNotifier<ScrollProgress> scroller, ValueNotifier<IndicatorPosition> notifier) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateScrollIndicator(double? page, List<Size>? sizeList, ValueNotifier<ScrollProgress> scroller, ValueNotifier<IndicatorPosition> notifier) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited